<?php
if ( ! defined( 'ABSPATH' ) ) exit;
include_once( get_template_directory() . '/inc/class-cerberus-notices.php' );
class osetin_cerberus 
{

  const SEC_IN_DAY = 86400;

  private $cerberus_code = false;
  private $last_call_timestamp = false;
  private $last_successfull_call_timestamp = false;
  private $last_domain_checked = false;
  public $last_status_message = 'Theme has not been activated yet. Please enter your purchase code to activate.';
  public $last_status_code = 404;
  public $license_key = false;


  function __construct(){
    $this->cerberus_code = get_option('cerberus_code');
    if($this->cerberus_code){
      $cerberus_code_arr = json_decode(openssl_decrypt($this->cerberus_code, 'aes-256-ecb', 'cerberus'), true);
      $this->last_status_message      = $cerberus_code_arr['last_status_message'];
      $this->last_status_code         = $cerberus_code_arr['last_status_code'];
      $this->license_key              = $cerberus_code_arr['license_key'];
      $this->last_call_timestamp      = $cerberus_code_arr['last_call_timestamp'];
      $this->last_successfull_call_timestamp   = $cerberus_code_arr['last_successfull_call_timestamp'];
      $this->last_domain_checked      = $cerberus_code_arr['last_domain_checked'];
    }else{
      // OLD VERSION RE-CHECK
      $old_key = get_option('options_license_key');
      if($old_key){
        delete_option('options_license_key');
        $this->verify_license_key($old_key);
      }
    }

  }
  
  function udpate_cerberus_code(){
    if($this->license_key){
      $cerberus_code_arr = array(
        'license_key' => $this->license_key, 
        'last_call_timestamp' => $this->last_call_timestamp, 
        'last_successfull_call_timestamp' => $this->last_successfull_call_timestamp, 
        'last_domain_checked' => $this->last_domain_checked, 
        'last_status_code' => $this->last_status_code, 
        'last_status_message' => $this->last_status_message);

      $this->cerberus_code = openssl_encrypt (json_encode($cerberus_code_arr), 'aes-256-ecb', 'cerberus');
      update_option('cerberus_code', $this->cerberus_code, true);
    }else{
      $this->delete_license_key();
    }
  }


  function process_response($response_body){
    $response = json_decode($response_body, true);
    if(!isset($response['status']) || empty($response['status'])){
      // bad response from server
      \osetin\cerberus\Notices::add_notice('theme_license_connection_error');
      $this->last_status_code = 500;
      $this->last_status_message = 'Connection Error. Please try again in a few minutes or contact us via email activation@pinsupreme.com. Code: KDF734HJ';
    }else{
      $this->last_status_code = $response['status'];
      $this->last_status_message = $response['message'];
      switch ($response['status']) {
        case 404:
          \osetin\cerberus\Notices::add_notice('theme_license_deactivate');
          break;
        case 422:
          \osetin\cerberus\Notices::add_notice('theme_license_status_422');
          break;
        case 200:
          $this->last_successfull_call_timestamp = $response['timestamp'];
          \osetin\cerberus\Notices::add_notice('theme_license_activate');
          break;
        default:
          $this->last_status_code = 500;
          $this->last_status_message = 'Invalid Status Code';
          break;
      }
    }
  }

  function verify_license_key($purchase_code) {
    if(empty($purchase_code)) return ;

    // connect
    $post = array(
      '_nonce'                  => wp_create_nonce('activate_licence'),
      'theme_unique_name'       => OSETIN_THEME_UNIQUE_ID,
      'purchase_code'           => $purchase_code, 
      'domain'                  => $_SERVER['SERVER_NAME'],
      'user_ip_activated_from'  => $this->get_user_ip(),
    );

    $url = "https://pinsupreme.com/cerberus/verify";


    $request = wp_remote_post( $url, array('body' => $post, 'sslverify ' => false, 'timeout' => 100));
    $this->last_call_timestamp = time();
    $this->license_key = $purchase_code;
    
    if(  !is_wp_error($request) || wp_remote_retrieve_response_code($request) === 200 ){ 
      $this->process_response($request['body']);
    }else{
      // bad connection
      \osetin\cerberus\Notices::add_notice('theme_license_connection_error');
      $this->last_status_code = 503;
      $this->last_status_message = 'Connection Error. Please try again in a few minutes or contact us via email activation@pinsupreme.com. Code: SDK28347S. ';
      if(is_wp_error($request)){
        error_log($request->get_error_message());
        $this->last_status_message.= $request->get_error_message();
      }
    }
    $this->udpate_cerberus_code();
  }

  function delete_license_key(){ 
    $this->cerberus_code = false;
    $this->last_status_message = 'Theme has not been activated yet. Please enter your purchase code to activate.';
    $this->last_status_code = 404;
    $this->license_key = false;
    $this->last_call_timestamp = false;
    $this->last_domain_checked = false;

    delete_option('cerberus_code');
    \osetin\cerberus\Notices::add_notice('theme_license_deactivate');
    
    return true;

  }

  function get_last_connection_date(){

  }
    
  function cerberus_mode(){
    return ($this->last_check_is_still_valid() === true);
  }
  

  function last_check_is_still_valid(){
    // never called with success
    if(($this->last_call_timestamp == false) || ($this->last_successfull_call_timestamp == false)) return false;

    $days_since_last_successfull_call = (time() - $this->last_successfull_call_timestamp)/self::SEC_IN_DAY;

    // success within last week
    if($days_since_last_successfull_call < 7){
      return true;
    }

    if($days_since_last_successfull_call > 50){
      return false;
    }

    // 7 - 43, try recalling if not called within last 3 days
    $days_since_last_call = (time() - $this->last_call_timestamp)/self::SEC_IN_DAY;
    if($days_since_last_call >= 3) $this->verify_license_key($this->license_key);


    // recalculate when was last successful call
    $days_since_last_successfull_call = (time() - $this->last_successfull_call_timestamp)/self::SEC_IN_DAY;

    return ($days_since_last_successfull_call < 7);
  }


  

  function get_user_ip(){
    if ( ! empty( $_SERVER['HTTP_CLIENT_IP'] ) ){
      $ip = $_SERVER['HTTP_CLIENT_IP'];
    }elseif ( ! empty( $_SERVER['HTTP_X_FORWARDED_FOR'] ) ){
      $ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
    }else{
      $ip = $_SERVER['REMOTE_ADDR'];
    }

    return $ip;
  }


}





function osetin_cerberus_init(){
  //add_action( 'wp_ajax_osetin_cerberus_submit_code', 'osetin_cerberus_submit_code' );
  //add_action( 'wp_ajax_nopriv_osetin_cerberus_submit_code', 'osetin_cerberus_submit_code' );
}


function osetin_cerberus_submit_code(){
  $cerberus = new osetin_cerberus();
  if(isset($_POST['key']) && !empty($_POST['key'])){
    $cerberus->verify_license_key($_POST['key']);
  }else{
    $cerberus->delete_license_key();
  }
  echo wp_send_json(array('status' => $cerberus->last_status_code, 'message' => $cerberus->last_status_message));
  exit();  
}
?>